@@ -10,7 +10,7 @@ import asyncio
 import io
 from concurrent.futures import Executor
 from dataclasses import dataclass, field
-from typing import Optional, Tuple, Union
+from typing import Generic, Optional, Tuple, TypeVar, Union
 
 
 BufferType = Union[bytes, memoryview]
@@ -51,6 +51,14 @@ class ReadReq:
     byte_range: Optional[Tuple[int, int]] = None
 
 
+T = TypeVar("T")
+
+
+@dataclass
+class Future(Generic[T]):
+    obj: Optional[T] = None
+
+
 @dataclass
 class WriteIO:
     path: str
